@@ -1,6 +1,6 @@
 #' @title Mann-Whitney-U-Test
 #' @name mwu
-#' @description This function performs a Mann-Whitney-U-Test (or \code{Wilcoxon rank sum test},
+#' @description This function performs a Mann-Whitney-U-Test (or Wilcoxon rank sum test,
 #'                see \code{\link{wilcox.test}} and \code{\link[coin]{wilcox_test}})
 #'                for \code{x}, for each group indicated by \code{grp}. If \code{grp}
 #'                has more than two categories, a comparison between each combination of
@@ -8,13 +8,13 @@
 #'                The function reports U, p and Z-values as well as effect size r
 #'                and group-rank-means.
 #'
-#' @param x Numeric vector / variable, where the Mann-Whitney-U-Test should be applied to
-#' @param grp Grouping variable indicating the groups that should be used for comparison
+#' @param x Numeric vector or variable.
+#' @param grp Grouping variable indicating the groups that should be used for comparison.
 #' @param distribution Indicates how the null distribution of the test statistic should be computed.
 #'          May be one of \code{"exact"}, \code{"approximate"} or \code{"asymptotic"}
 #'          (default). See \code{\link[coin]{wilcox_test}} for details.
-#' @param weights Integer valued weights for the observations. By default,
-#'          this is \code{NULL}.
+#' @inheritParams prop
+#'
 #' @return (Invisibly) returns a data frame with U, p and Z-values for each group-comparison
 #'         as well as effect-size r; additionally, group-labels and groups' n's are
 #'         also included.
@@ -38,7 +38,7 @@
 #' @importFrom coin wilcox_test pvalue statistic
 #' @importFrom sjmisc to_value get_labels recode_to
 #' @export
-mwu <- function(x, grp, distribution = "asymptotic", weights = NULL) {
+mwu <- function(x, grp, distribution = "asymptotic", weight.by = NULL) {
   # coerce factor and character to numeric
   if (is.factor(grp) || is.character(grp)) grp <- sjmisc::to_value(grp)
   # group "counter" (index) should start with 1, not 0
@@ -58,21 +58,25 @@ mwu <- function(x, grp, distribution = "asymptotic", weights = NULL) {
         ysub <- grp[which(grp == grp_values[i] | grp == grp_values[j])]
         # only use rows with non-missings
         ysub <- ysub[which(!is.na(xsub))]
+
         # adjust weights, pick rows from subgroups (see above)
-        if (!is.null(weights)) {
-          wsub <- as.integer(stats::na.omit(weights[which(!is.na(xsub))]))
-        }
+        if (!is.null(weight.by))
+          wsub <- as.integer(stats::na.omit(weight.by[which(!is.na(xsub))]))
+
         # remove missings
         xsub <- as.numeric(stats::na.omit(xsub))
         ysub.n <- stats::na.omit(ysub)
+
         # grouping variable is a factor
         ysub <- as.factor(ysub.n)
-        if (is.null(weights)) {
+
+        # perfom wilcox test
+        if (is.null(weight.by)) {
           wt <- coin::wilcox_test(xsub ~ ysub, distribution = distribution)
         } else {
           wt <- coin::wilcox_test(xsub ~ ysub,
                                   distribution = distribution,
-                                  weights = as.formula("~wsub"))
+                                  weight.by = as.formula("~wsub"))
         }
         # compute statistics
         u <- as.numeric(coin::statistic(wt, type = "linear"))
@@ -82,9 +86,11 @@ mwu <- function(x, grp, distribution = "asymptotic", weights = NULL) {
         w <- stats::wilcox.test(xsub, ysub.n, paired = TRUE)$statistic
         rkm.i <- mean(rank(xsub)[which(ysub.n == grp_values[i])], na.rm = TRUE)
         rkm.j <- mean(rank(xsub)[which(ysub.n == grp_values[j])], na.rm = TRUE)
+
         # compute n for each group
         n_grp1 <- length(xsub[which(ysub.n == grp_values[i])])
         n_grp2 <- length(xsub[which(ysub.n == grp_values[j])])
+
         # generate result data frame
         df <- rbind(df, cbind(grp1 = grp_values[i], grp1.label = labels[i],
                               grp1.n = n_grp1, grp2 = grp_values[j], grp2.label = labels[j],
@@ -107,6 +113,7 @@ mwu <- function(x, grp, distribution = "asymptotic", weights = NULL) {
   df[["r"]] <- as.numeric(as.character(df[["r"]]))
   df[["rank.mean.grp1"]] <- as.numeric(as.character(df[["rank.mean.grp1"]]))
   df[["rank.mean.grp2"]] <- as.numeric(as.character(df[["rank.mean.grp2"]]))
+
   # prepare a data frame that can be used for 'sjt.df'.
   tab.df <- data.frame(Groups = sprintf("%s<br>%s", df$grp1.label, df$grp2.label),
                        N = sprintf("%s<br>%s", df$grp1.n, df$grp2.n),
@@ -116,6 +123,7 @@ mwu <- function(x, grp, distribution = "asymptotic", weights = NULL) {
                        Z = sprintf("%.3f", df$z),
                        'Effect Size' = sprintf("%.3f", df$r),
                        p = sprintf("%.3f", df$p))
+
   # replace 0.001 with <0.001
   levels(tab.df$p)[which(levels(tab.df$p) == "0.001")] <- "<0.001"
   # return both data frames
