@@ -1,10 +1,10 @@
 #' @title Get predictor and response variables from models
 #' @name pred_vars
 #'
-#' @description \code{pred_vars} and \code{resp_var} return the names of a
+#' @description \code{pred_vars()} and \code{resp_var()} return the names of a
 #'                model's predictor or response variables as character vector.
 #'                \cr \cr
-#'                \code{resp_val} returns the values of the model's response
+#'                \code{resp_val()} returns the values of the model's response
 #'                vector.
 #'
 #' @param x A fitted model.
@@ -38,7 +38,7 @@ resp_var <- function(x) {
 #' @importFrom nlme getResponse
 #' @export
 resp_val <- function(x) {
-  if (class(x) == "lme")
+  if (inherits(x, "lme"))
     as.vector(nlme::getResponse(x))
   else
     as.vector(stats::model.frame(x)[[resp_var(x)]])
