@@ -1,8 +1,9 @@
-#' @title Proportion of values in a vector
+#' @title Proportions of values in a vector
 #' @name prop
 #'
-#' @description This function calculates the proportion of a value or category
-#'                in a variable.
+#' @description \code{prop()} calculates the proportion of a value or category
+#'                in a variable. \code{props()} does the same, but allows for
+#'                multiple logical conditions in one statement.
 #'
 #' @param data A data frame. May also be a grouped data frame (see 'Examples').
 #' @param ... One or more value pairs of comparisons (logical predicates). Put
@@ -18,6 +19,14 @@
 #'          percentage.
 #' @inheritParams reliab_test
 #'
+#' @details \code{prop()} only allows one logical statement per comparison,
+#'          while \code{props()} allows multiple logical statements per comparison.
+#'          However, \code{prop()} supports weighting of variables before calculating
+#'          proportions, and comparisons may also be quoted. Hence, \code{prop()}
+#'          also processes comparisons, which are passed as character vector
+#'          (see 'Examples').
+#'
+#'
 #' @return For one condition, a numeric value with the proportion of the values
 #'         inside a vector. For more than one condition, a tibble with one column
 #'         of conditions and one column with proportions. For grouped data frames,
@@ -33,14 +42,18 @@
 #' # expression may also be completely quoted
 #' prop(efc, "e42dep == 1")
 #'
+#' # use "props()" for multiple logical statements
+#' props(efc, e17age > 70 & e17age < 80)
+#'
 #' # proportion of value 1 in e42dep, and all values greater
-#' # than 2 in e42dep, excluding missing values. will return a tibble
-#' prop(efc, e42dep == 1, e42dep > 2, na.rm = TRUE)
+#' # than 2 in e42dep, including missing values. will return a tibble
+#' prop(efc, e42dep == 1, e42dep > 2, na.rm = FALSE)
 #'
 #' # for factors or character vectors, use quoted or unquoted values
 #' library(sjmisc)
 #' # convert numeric to factor, using labels as factor levels
 #' efc$e16sex <- to_label(efc$e16sex)
+#' efc$n4pstu <- to_label(efc$n4pstu)
 #'
 #' # get proportion of female older persons
 #' prop(efc, e16sex == female)
@@ -48,6 +61,12 @@
 #' # get proportion of male older persons
 #' prop(efc, e16sex == "male")
 #'
+#' # "props()" needs quotes around non-numeric factor levels
+#' props(efc,
+#'   e17age > 70 & e17age < 80,
+#'   n4pstu == 'Care Level 1' | n4pstu == 'Care Level 3'
+#' )
+#'
 #' # also works with pipe-chains
 #' library(dplyr)
 #' efc %>% prop(e17age > 70)
@@ -63,17 +82,45 @@
 #'   group_by(c161sex, c172code) %>%
 #'   prop(e42dep > 2, e16sex == 1)
 #'
+#' # same for "props()"
+#' efc %>%
+#'   select(e42dep, c161sex, c172code, c12hour, n4pstu) %>%
+#'   group_by(c161sex, c172code) %>%
+#'   props(
+#'     e42dep > 2,
+#'     c12hour > 20 & c12hour < 40,
+#'     n4pstu == 'Care Level 1' | n4pstu == 'Care Level 3'
+#'   )
+#'
 #' @importFrom tibble tibble as_tibble
 #' @importFrom dplyr bind_cols bind_rows
 #' @importFrom sjmisc get_label get_labels to_value
 #' @export
-prop <- function(data, ..., weight.by = NULL, na.rm = FALSE, digits = 4) {
+prop <- function(data, ..., weight.by = NULL, na.rm = TRUE, digits = 4) {
   # check argument
   if (!is.data.frame(data)) stop("`data` needs to be a data frame.", call. = F)
 
   # get dots
   dots <- match.call(expand.dots = FALSE)$`...`
 
+  proportions(data, dots, weight.by, na.rm, digits, multi_logical = FALSE)
+}
+
+
+#' @rdname prop
+#' @export
+props <- function(data, ..., na.rm = TRUE, digits = 4) {
+  # check argument
+  if (!is.data.frame(data)) stop("`data` needs to be a data frame.", call. = F)
+
+  # get dots
+  dots <- match.call(expand.dots = FALSE)$`...`
+
+  proportions(data, dots, NULL, na.rm, digits, multi_logical = TRUE)
+}
+
+
+proportions <- function(data, dots, weight.by, na.rm, digits, multi_logical) {
   # remember comparisons
   comparisons <- lapply(dots, function(x) {
     # to character, and remove spaces and quotes
@@ -100,7 +147,10 @@ prop <- function(data, ..., weight.by = NULL, na.rm = FALSE, digits = 4) {
       .d <- grps$data[[i]]
 
       # iterate dots (comparing conditions)
-      result <- lapply(dots, get_proportion, .d, weight.by, na.rm, digits)
+      if (multi_logical)
+        result <- lapply(dots, get_multiple_proportion, .d, na.rm, digits)
+      else
+        result <- lapply(dots, get_proportion, .d, weight.by, na.rm, digits)
 
       # bind all proportion values to data frame. we need to
       # transform here to get each value in a new colummn
@@ -145,7 +195,10 @@ prop <- function(data, ..., weight.by = NULL, na.rm = FALSE, digits = 4) {
 
   } else {
     # iterate dots (comparing conditions)
-    result <- lapply(dots, get_proportion, data, weight.by, na.rm, digits)
+    if (multi_logical)
+      result <- lapply(dots, get_multiple_proportion, data, na.rm, digits)
+    else
+      result <- lapply(dots, get_proportion, data, weight.by, na.rm, digits)
 
     # if we have more than one proportion, return a tibble. this allows us
     # to save more information, the condition and the proportion value
@@ -200,4 +253,16 @@ get_proportion <- function(x, data, weight.by, na.rm, digits) {
 
   # get proportion
   round(sum(dummy, na.rm = T) / length(dummy), digits = digits)
-}
\ No newline at end of file
+}
+
+
+get_multiple_proportion <- function(x, data, na.rm, digits) {
+  # evaluate argument
+  dummy <- with(data, eval(parse(text = deparse(x))))
+
+  # remove missings?
+  if (na.rm) dummy <- na.omit(dummy)
+
+  # get proportion
+  round(sum(dummy, na.rm = T) / length(dummy), digits = digits)
+}
